# ConnectorSpec

The specification of the Connector
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | A descriptive name for the connector | 
**name_slug** | **str** | A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.  | [optional] 
**org_id** | **str** | Unique identifier | 
**connector_type** | **str** | The type of the connector | 
**service_account_id** | **str** | Service account user GUID used to deploy the connector | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


